diff --git a/boost/test/tools/assertion.hpp b/boost/test/tools/assertion.hpp
index 17a9ab9..1919b32 100755
--- a/boost/test/tools/assertion.hpp
+++ b/boost/test/tools/assertion.hpp
@@ -28,6 +28,7 @@
 #ifndef BOOST_NO_CXX11_RVALUE_REFERENCES
 #include <utility>
 #endif
+#include <boost/move/move.hpp>
 
 #include <boost/test/detail/suppress_warnings.hpp>
 
@@ -123,7 +124,7 @@ namespace op {
 //____________________________________________________________________________//
 
 #ifndef BOOST_NO_CXX11_DECLTYPE
-#   define DEDUCE_RESULT_TYPE( oper ) typename boost::remove_reference<decltype(boost::declval<Lhs>() oper boost::declval<Rhs>() )>::type 
+#   define DEDUCE_RESULT_TYPE( oper ) typename boost::remove_reference<decltype((boost::declval<Lhs>() oper boost::declval<Rhs>() ))>::type
 #else
 #   define DEDUCE_RESULT_TYPE( oper ) bool
 #endif
@@ -259,7 +260,7 @@ public:
     {                                                           \
         return binary_expr<ExprType,T,op::name<ValType,T> >(    \
             *static_cast<ExprType const*>(this),                \
-            std::forward<T>(rhs) );                             \
+            boost::forward<T>(rhs) );                             \
     }                                                           \
 /**/
 #else
@@ -320,7 +321,7 @@ public:
     // Constructor
 #ifndef BOOST_NO_CXX11_RVALUE_REFERENCES
     explicit                    value_expr( T&& val )
-    : m_value( std::forward<T>(val) )
+    : m_value( boost::forward<T>(val) )
 #else
     explicit                    value_expr( T const& val )
     : m_value( val )
@@ -391,7 +392,7 @@ public:
 #ifndef BOOST_NO_CXX11_RVALUE_REFERENCES
     binary_expr( LExpr const& lhs, Rhs&& rhs )
     : m_lhs( lhs )
-    , m_rhs( std::forward<Rhs>(rhs) )
+    , m_rhs( boost::forward<Rhs>(rhs) )
     {}
 #else
     binary_expr( LExpr const& lhs, Rhs const& rhs )
@@ -442,7 +443,7 @@ public:
 #ifndef BOOST_NO_CXX11_RVALUE_REFERENCES
     operator->*( T&& v ) const
     {
-        return value_expr<T>( std::forward<T>( v ) );
+        return value_expr<T>( boost::forward<T>( v ) );
     }
 #else
     operator->*( T const& v )  const
diff --git a/boost/test/utils/is_forward_iterable.hpp b/boost/test/utils/is_forward_iterable.hpp
index ca03731..7a92d44 100755
--- a/boost/test/utils/is_forward_iterable.hpp
+++ b/boost/test/utils/is_forward_iterable.hpp
@@ -27,6 +27,7 @@
 
 // Boost
 #include <boost/utility/declval.hpp>
+#include <boost/utility/enable_if.hpp>
 #include <boost/type_traits/is_same.hpp>
 #include <boost/type_traits/remove_reference.hpp>
 #include <boost/type_traits/remove_cv.hpp>
@@ -69,7 +70,7 @@ struct is_present : mpl::true_ {};
 
 struct is_forward_iterable_impl {
     template<typename T>
-    static typename std::enable_if<
+    static typename boost::enable_if_c<
         is_present<typename T::const_iterator>::value            &&
         is_present<typename T::value_type>::value                &&
         is_present<decltype(boost::declval<T>().size())>::value  &&
@@ -79,14 +80,14 @@ struct is_forward_iterable_impl {
     test(int);
 
     template<typename> 
-    static std::false_type  test(...); 
+    static mpl::false_  test(...);
 }; 
 
 } // namespace ut_detail
 
 template<typename T> 
 struct is_forward_iterable { 
-    typedef decltype(ut_detail::is_forward_iterable_impl::test<typename std::remove_reference<T>::type>(0)) type;
+    typedef decltype(ut_detail::is_forward_iterable_impl::test<typename boost::remove_reference<T>::type>(0)) type;
     enum { value = type::value };
 }; 
 
